==> jc-1.4.0.tar.gz: javax/swing/JScrollPane__24ScrollBar.h <==
// public class javax.swing.JScrollPane$ScrollBar

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 6a96f3b336d301aa javax_swing_JScrollBar
// @dep_class eda39eb0da2f6ae0 javax_swing_JScrollPane__24ScrollBar

// header file dependencies
// @dep_header javax_swing_JScrollBar

#include "javax/swing/JScrollBar.h"

#ifndef _JC_javax_swing_JScrollPane__24ScrollBar_H_
#define _JC_javax_swing_JScrollPane__24ScrollBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JScrollPane$object;

// Typedefs
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs	_jc_javax_swing_JScrollPane__24ScrollBar$sub_refs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs	_jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$refs	_jc_javax_swing_JScrollPane__24ScrollBar$refs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$nonrefs	_jc_javax_swing_JScrollPane__24ScrollBar$nonrefs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$object	_jc_javax_swing_JScrollPane__24ScrollBar$object;

typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vmethods	_jc_javax_swing_JScrollPane__24ScrollBar$vmethods;
typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vtable	_jc_javax_swing_JScrollPane__24ScrollBar$vtable;
typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vtype	_jc_javax_swing_JScrollPane__24ScrollBar$vtype;

// Constructors
extern void _jc_javax_swing_JScrollPane__24ScrollBar$method$_init$9e35863789c95831(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, struct _jc_javax_swing_JScrollPane$object *, jint);

// Virtual methods
extern jint _jc_javax_swing_JScrollPane__24ScrollBar$method$getBlockIncrement$8fa3f1cefd6db909(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint);
extern jint _jc_javax_swing_JScrollPane__24ScrollBar$method$getUnitIncrement$2306867ed5cd5eff(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JScrollPane__24ScrollBar$method_info$getBlockIncrement$8fa3f1cefd6db909;
extern _jc_method _jc_javax_swing_JScrollPane__24ScrollBar$method_info$getUnitIncrement$2306867ed5cd5eff;

// Virtual methods structure
struct _jc_javax_swing_JScrollPane__24ScrollBar$vmethods {
	jint	(*getBlockIncrement$8fa3f1cefd6db909)(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint);
	jint	(*getUnitIncrement$2306867ed5cd5eff)(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint);
};

// Vtable
struct _jc_javax_swing_JScrollPane__24ScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JScrollBar$vmethods	javax_swing_JScrollBar;
	_jc_javax_swing_JScrollPane__24ScrollBar$vmethods	javax_swing_JScrollPane__24ScrollBar;
};

// Vtype
struct _jc_javax_swing_JScrollPane__24ScrollBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JScrollPane__24ScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs {
	struct _jc_javax_swing_JScrollPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JScrollPane__24ScrollBar$refs {
    _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs	javax_swing_JScrollPane__24ScrollBar;
    _jc_javax_swing_JScrollBar$sub_refs	javax_swing_JScrollBar;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JScrollPane__24ScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JScrollBar$sub_nonrefs	javax_swing_JScrollBar;
    _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs	javax_swing_JScrollPane__24ScrollBar;
};

// Object instance structure
struct _jc_javax_swing_JScrollPane__24ScrollBar$object {
	_jc_javax_swing_JScrollPane__24ScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JScrollPane__24ScrollBar$vtype	*vtype;
	_jc_javax_swing_JScrollPane__24ScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JScrollPane__24ScrollBar$vtype _jc_javax_swing_JScrollPane__24ScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JScrollPane__24ScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JScrollPane__24ScrollBar$class_object;

#endif	/* _JC_javax_swing_JScrollPane__24ScrollBar_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JScrollPane__24ScrollBar.h <==
// public class javax.swing.JScrollPane$ScrollBar

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 6a96f3b336d301aa javax_swing_JScrollBar
// @dep_class eda39eb0da2f6ae0 javax_swing_JScrollPane__24ScrollBar

// header file dependencies
// @dep_header javax_swing_JScrollBar

#include "javax/swing/JScrollBar.h"

#ifndef _JC_javax_swing_JScrollPane__24ScrollBar_H_
#define _JC_javax_swing_JScrollPane__24ScrollBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JScrollPane$object;

// Typedefs
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs	_jc_javax_swing_JScrollPane__24ScrollBar$sub_refs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs	_jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$refs	_jc_javax_swing_JScrollPane__24ScrollBar$refs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$nonrefs	_jc_javax_swing_JScrollPane__24ScrollBar$nonrefs;
typedef struct _jc_javax_swing_JScrollPane__24ScrollBar$object	_jc_javax_swing_JScrollPane__24ScrollBar$object;

typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vmethods	_jc_javax_swing_JScrollPane__24ScrollBar$vmethods;
typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vtable	_jc_javax_swing_JScrollPane__24ScrollBar$vtable;
typedef const struct _jc_javax_swing_JScrollPane__24ScrollBar$vtype	_jc_javax_swing_JScrollPane__24ScrollBar$vtype;

// Constructors
extern void _jc_javax_swing_JScrollPane__24ScrollBar$method$_init$9e35863789c95831(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, struct _jc_javax_swing_JScrollPane$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_JScrollPane__24ScrollBar$method$getBlockIncrement$8fa3f1cefd6db909(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JScrollPane__24ScrollBar$method$getUnitIncrement$2306867ed5cd5eff(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JScrollPane__24ScrollBar$method_info$getBlockIncrement$8fa3f1cefd6db909;
extern _jc_method _jc_javax_swing_JScrollPane__24ScrollBar$method_info$getUnitIncrement$2306867ed5cd5eff;

// Virtual methods structure
struct _jc_javax_swing_JScrollPane__24ScrollBar$vmethods {
	jint	(*getBlockIncrement$8fa3f1cefd6db909)(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint) _JC_JCNI_ATTR;
	jint	(*getUnitIncrement$2306867ed5cd5eff)(_jc_env *, struct _jc_javax_swing_JScrollPane__24ScrollBar$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JScrollPane__24ScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JScrollBar$vmethods	javax_swing_JScrollBar;
	_jc_javax_swing_JScrollPane__24ScrollBar$vmethods	javax_swing_JScrollPane__24ScrollBar;
};

// Vtype
struct _jc_javax_swing_JScrollPane__24ScrollBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JScrollPane__24ScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs {
	struct _jc_javax_swing_JScrollPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JScrollPane__24ScrollBar$refs {
    _jc_javax_swing_JScrollPane__24ScrollBar$sub_refs	javax_swing_JScrollPane__24ScrollBar;
    _jc_javax_swing_JScrollBar$sub_refs	javax_swing_JScrollBar;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JScrollPane__24ScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JScrollBar$sub_nonrefs	javax_swing_JScrollBar;
    _jc_javax_swing_JScrollPane__24ScrollBar$sub_nonrefs	javax_swing_JScrollPane__24ScrollBar;
};

// Object instance structure
struct _jc_javax_swing_JScrollPane__24ScrollBar$object {
	_jc_javax_swing_JScrollPane__24ScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JScrollPane__24ScrollBar$vtype	*vtype;
	_jc_javax_swing_JScrollPane__24ScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JScrollPane__24ScrollBar$vtype _jc_javax_swing_JScrollPane__24ScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JScrollPane__24ScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JScrollPane__24ScrollBar$class_object;

#endif	/* _JC_javax_swing_JScrollPane__24ScrollBar_H_ */
